pitchtools.ChromaticObject
==========================

.. inheritance-diagram:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
